@@ -10,7 +10,7 @@ use base 'FLV::Base';
 
 use FLV::Util;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 =head1 NAME
 
@@ -104,6 +104,18 @@ sub get_info
    );
 }
 
+=item $self->get_time()
+
+Returns the time in milliseconds for this tag.
+
+=cut
+
+sub get_time
+{
+   my $self = shift;
+   return $self->{start};
+}
+
 1;
 
 __END__
