@@ -10,7 +10,7 @@ use base 'FLV::Base';
 
 use FLV::Util;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 =for stopwords codec
 
@@ -226,6 +226,18 @@ sub is_keyframe
    return $self->{type} && 1 == $self->{type} ? 1 : undef;
 }
 
+=item $self->get_time()
+
+Returns the time in milliseconds for this tag.
+
+=cut
+
+sub get_time
+{
+   my $self = shift;
+   return $self->{start};
+}
+
 1;
 
 __END__
